@@ -32,6 +32,14 @@ RESERVED_IDENTIFIERS = [
 BINANCE_API_KEY = "binance_api_key"
 BINANCE_SECRET_KEY = "binance_secret_key"
 
-TRADING_SYMBOL = "TRADING_SYMBOL"
-
 CHECK_PENDING_ORDERS = "CHECK_PENDING_ORDERS"
+
+# Configuration
+TRADING_SYMBOL = "TRADING_SYMBOL"
+CCXT_ENABLED = "CCXT_ENABLED"
+API_KEY = "API_KEY"
+SECRET_KEY = "SECRET_KEY"
+MARKET = "MARKET"
+TRACK_PORTFOLIO_FROM = "TRACK_PORTFOLIO_FROM"
+SQLITE_ENABLED = "SQLITE_ENABLED"
+PORTFOLIOS = "PORTFOLIOS"
